# EnergyPlus API Python Bindings

This package provides the Python bindings for accessing the EnergyPlus API to do:
 - Functional API calls into the EnergyPlus library
 - Python plugins to allow EnergyPlus to call your python scripts
 - Runtime actuation where you can control the EnergyPlus time stepping through callbacks
 - Data transfer API where you can get sensor/meter data from EnergyPlus and set actuator values during a simulation
 - In the future, access helper methods for creating input structures programmatically
